@@ -6,7 +6,8 @@ droplevels.lfactor <- function(x, ...) {
 	cookie_cutter <- labels %in% x
 	labels <- labels[cookie_cutter]
 	levels <- levels[cookie_cutter]
-	attr(x, "levels") <- labels
-	attr(x, "llevels") <- levels
-	return(x)
+	return(lfactor(switchllevels(x), levels=levels, labels=labels))
+	#attr(x, "levels") <- labels
+	#attr(x, "llevels") <- levels
+	#return(x)
 }
