@@ -12,4 +12,9 @@ inlf <- function(x, table) {
   	m2 <- match(x=as.character(x), table=as.character(switchllevels(table)), nomatch=0)
   }
   ((m1 > 0) | (m2 > 0))
-}
\ No newline at end of file
+}
+
+setMethod("%in%", signature(x="lfactor"), inlf)
+setMethod("%in%", signature(table="lfactor"), inlf)
+setMethod("%in%", signature(x="lfactor", table="lfactor"), inlf) 
+
